function MakeFig6_1()
% Function to reproduce Fig. 6.1
% Wavelength-dependence of decay rate EFs for a dipole in air emitting
% close to a planar silver or gold surface.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.1', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);


% dielectric constant of outside medium (real positive)
epsilonM=1.0; % air

% loop twice for silver and gold cases
for nn=1:2

    if nn==1 % silver
        % wavelengths (column)
        lambda=transpose(200:2:800);
        epsilonIn=epsAg(lambda);
        sMetal='Ag';
    else % gold
        % wavelengths (column)
        lambda=transpose(400:10:1000);
        epsilonIn=epsAu(lambda);
        sMetal='Au';
    end        
    
    % Solve problem dipole emission problem for d=1,5,10,20 nm
    nNbStep=5000; % for integrals
    disp(['Computations for ' sMetal]);
    stAllMd1=PlnSinglePlaneDecayRateEFs(epsilonM,lambda,epsilonIn,1,nNbStep);
    stAllMd5=PlnSinglePlaneDecayRateEFs(epsilonM,lambda,epsilonIn,5,nNbStep);
    stAllMd10=PlnSinglePlaneDecayRateEFs(epsilonM,lambda,epsilonIn,10,nNbStep);
    stAllMd20=PlnSinglePlaneDecayRateEFs(epsilonM,lambda,epsilonIn,20,nNbStep);

    % plot results
    % top plot (MTotPerp)
    subplot(2,2,nn);

    h=semilogy(lambda,stAllMd1.MTotPerp, '-', ...
        lambda,stAllMd5.MTotPerp, '-', ...
        lambda,stAllMd10.MTotPerp, '-');
    line(lambda,stAllMd1.MTotPerpESA,'LineStyle',':','Color',get(h(1),'Color'));
    line(lambda,stAllMd5.MTotPerpESA,'LineStyle',':','Color',get(h(2),'Color'));
    line(lambda,stAllMd10.MTotPerpESA,'LineStyle',':','Color',get(h(3),'Color'));
    
    set(gca,'YLim',[1 1.2e6]);
    title(['Total M_{Tot} - Perp dipole in air on ' sMetal]);
    xlabel('Wavelength [nm]');
    ylabel('M_{Tot}');
    legend({'d=1nm','d=5mn','d=10nm','d=1nm (ESA)', ...
        'd=5mn (ESA)','d=10nm (ESA)'},'Location','NorthEast');
    
    % bottom plot (MRad)
    subplot(2,2,2+nn);

    h=semilogy(lambda,stAllMd1.MRadPerp, '-', ...
        lambda,stAllMd5.MRadPerp, '--', ...
        lambda,stAllMd10.MRadPerp, '-', ...
        lambda,stAllMd20.MRadPerp, '--');
    legend({'d=1nm','d=5mn','d=10nm','d=20nm'},'Location','South');
    line(lambda,stAllMd1.MRadPara,'LineStyle','-','Color',get(h(1),'Color'));
    line(lambda,stAllMd5.MRadPara,'LineStyle','--','Color',get(h(2),'Color'));
    line(lambda,stAllMd10.MRadPara,'LineStyle','-','Color',get(h(3),'Color'));
    line(lambda,stAllMd20.MRadPara,'LineStyle','--','Color',get(h(4),'Color'));
    
    set(gca,'YLim',[0.01 4]);
    title(['Radiative M_{Rad} - dipole in air on ' sMetal]);
    xlabel('Wavelength [nm]');
    ylabel('M_{Rad}');
    text(600,0.08,'Para');
    text(600,2,'Perp');
end