function MakeFig6_16()
% Function to reproduce Fig. 6.16
% Wavelength dependence of the maximum and minimum LFIEF
% on a spheroid surface for oblate and prolate (aspect ratio of h=3)
% silver spheroid in water or gold spheroid in air.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information


% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1.3;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.16', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% aspect ratio
h=3;
% get geometrical factors for oblate and prolate spheroids
stEllGobl=EllOblateGeomFact(h,1,'L');
stEllGpro=EllProlateGeomFact(h,1,'L');

% wavelength in nm (column vector)
lambda=transpose(200:1:1000);
eAg=epsAg(lambda);
eAu=epsAu(lambda);

% sphere case:
stEllGsph=EllSphereGeomFact(1,'L');
stEllEMsphAg=EllEMproperties(stEllGsph,lambda,1.77,eAg,'L');
stEllEMsphAu=EllEMproperties(stEllGsph,lambda,1.0,eAu,'L');

% loop 4 times for each subplot
for nn=1:4
    if (nn==1 || nn==3) % prolate
        stEllG=stEllGpro;
        sTitle='Prolate spheroid, h=3';
    else % oblate
        stEllG=stEllGobl;
        sTitle='Oblate spheroid, h=3';
    end
    if (nn==1 || nn==2) % silver in water
        epsilonM=1.77;
        epsilonIn=eAg;
        stEllEMsph=stEllEMsphAg;
        sTitle=[sTitle ' - Ag in water'];
    else % gold in air
        epsilonM=1.0;
        epsilonIn=eAu;
        stEllEMsph=stEllEMsphAu;
        sTitle=[sTitle ' - Au in air'];
    end

    % computes EM properties (A's only)
    stEllEM=EllEMproperties(stEllG,lambda,epsilonM,epsilonIn,'L');
    
    % plot results
    subplot(2,2,nn);
    h=semilogy(lambda,stEllEM.Aperp1, '-', ...
        lambda,stEllEM.Aperp3, '-', ...
        lambda,stEllEMsph.Aperp1, '-');
    set(h,'LineWidth',1.5);
    line(lambda,stEllEM.Apara1,'LineStyle',':','LineWidth',1.5,'Color',get(h(1),'Color'));
    line(lambda,stEllEM.Apara3,'LineStyle',':','LineWidth',1.5,'Color',get(h(2),'Color'));
    line(lambda,stEllEMsph.Apara1,'LineStyle',':','LineWidth',1.5,'Color',get(h(3),'Color'));
    
    axis([200 1000 0.1 5e4]);
    title(sTitle);
    xlabel('Aspect ratio, h');
    ylabel('LFIEF');
    legend({'A_1^{perp}', 'A_3^{perp}', 'A_{sphere}^{perp}', ...
        'A_1^{//}'},'Location','NorthEast');
end