function MakeFig6_17()
% Function to reproduce Fig. 6.17
% Wavelength dependence of A_1^{perp}, maximum LFIEF on the surface
% (i.e. at the tip) for excitation along the long axis (x-axis)
% for silver or gold prolate (left) or oblate (right) spheroids of
% various aspect ratios.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information


% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1.3;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','Fig. 6.17', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);

% wavelength in nm (column vector)
lambda=transpose(300:1:1500);
eAg=epsAg(lambda);
eAu=epsAu(lambda);

% loop 4 times for each subplot
for nn=1:4
    if (nn==1 || nn==2) % h=1,3,7
        hArray=[1.000001 3 7]; % 1.000001 to model sphere without having to call EllSphereGeomFact
    else % h=2,5,10
        hArray=[2 5 10];
    end
    if (nn==1 || nn==3) % prolate
        stEllG=EllProlateGeomFact(hArray,1,'L');
        sTitle='Prolate spheroids';
        sLegLoc='SouthEast';
        lambdaMax=1500;
    else % oblate
        stEllG=EllOblateGeomFact(hArray,1,'L');
        sTitle='Oblate spheroids';
        sLegLoc='NorthEast';
        lambdaMax=1000;
    end

    % computes EM properties (A's only)
    stEllEMAgWat=EllEMproperties(stEllG,lambda,1.77,eAg,'L');
    stEllEMAuWat=EllEMproperties(stEllG,lambda,1.77,eAu,'L');
    stEllEMAuAir=EllEMproperties(stEllG,lambda,1.0,eAu,'L');
    
    % plot results
    subplot(2,2,nn);
    h=semilogy(lambda,stEllEMAgWat.Aperp1, '-');
    set(h,'LineWidth',1.5);
    legend({['h=' num2str(hArray(1))], ...
        ['h=' num2str(hArray(2))], ...
        ['h=' num2str(hArray(3))]},'Location',sLegLoc);
    hold on;
    h=semilogy(lambda,stEllEMAuWat.Aperp1, '--');
    set(h,'LineWidth',1.5);
    h=semilogy(lambda,stEllEMAuAir.Aperp1, ':');
    set(h,'LineWidth',1.5);
    text(350,2.5e5,0,{'Ag/Water (solid)','Au/Water (dashed)','Au/Air (dotted)'});
    
    axis([300 lambdaMax 10 8e5]);
    title(sTitle);
    xlabel('Wavelength [nm]');
    ylabel('Maximum LFIEF (A_1^{perp})');
    set(gca,'YGrid','on','YMinorGrid','off');
    hold off;
end