function MakeFig6_7()
% Function to reproduce Fig. 6.7
% Imaginary parts of epsilon for silver and gold (left)
% and quality factor of the LSP resonances
% in the ES approximation from Eq. 6.38 (right).
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% lambda in nm (column)
lambdaStep=0.5; % in nm
lambda=transpose(200:lambdaStep:1200);

% calculate epsilon for Ag and Au
eAg=epsAg(lambda);
eAu=epsAu(lambda);

eAgReal=real(eAg);
eAgImag=imag(eAg);
eAuReal=real(eAu);
eAuImag=imag(eAu);

% calculate d\epsilon'/d\lambda = 0.5/step *(eAgReal_{n+1} - eAgReal_{n-1})
nNbLambda=length(lambda);
deAgReal=0*lambda; % L x 1
deAgReal(2:(nNbLambda-1))=0.5/lambdaStep*(eAgReal(3:nNbLambda)-eAgReal(1:(nNbLambda-2)));
deAgReal(1)=deAgReal(2);
deAgReal(nNbLambda)=deAgReal(nNbLambda-1);
deAuReal=0*lambda; % L x 1
deAuReal(2:(nNbLambda-1))=0.5/lambdaStep*(eAuReal(3:nNbLambda)-eAuReal(1:(nNbLambda-2)));
deAuReal(1)=deAuReal(2);
deAuReal(nNbLambda)=deAuReal(nNbLambda-1);

QAg=-lambda.*deAgReal./(2*eAgImag);
QAu=-lambda.*deAuReal./(2*eAuImag);

% calculate values for small sphere in water
lambdaResAg=387;
lambdaResAu=518;

indResAg=find(lambda==lambdaResAg);
indResAu=find(lambda==lambdaResAu);


%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=3;
figWidth=3/4*scrsz(3);
figure('Name','Fig. 6.7', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% plot imag(epsilon)
subplot(1,2,1);
plot(lambda,eAuImag,'r',lambda,eAgImag,'b');
% format graph
axis([200 1200 0 6]);
xlabel('Wavelength [nm]');
ylabel('Im(\epsilon(\omega)');
legend('Gold','Silver');
title('Optical absorption');

% plot Q
subplot(1,2,2);
plot(lambda,QAu,'r',lambda,QAg,'b');
hold on;
plot([lambda(1) lambda(indResAg) lambda(indResAg)], ...
    [QAg(indResAg) QAg(indResAg) 0],'b:');
plot([lambda(1) lambda(indResAu) lambda(indResAu)], ...
    [QAu(indResAu) QAu(indResAu) 0],'r:');
% format graph
axis([300 1000 0 60]);
xlabel('Wavelength [nm]');
ylabel('Q-factor');
legend('Gold','Silver');
title('Resonance quality factor');




