function MakeFigE_3()
% Function to reproduce Fig. E.3
% Real and imaginary parts of epsilon for silver and gold
% using the analytical expressions of Appendix E.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

%%%%%%%%%%%%%%%%%%
% Computations
%%%%%%%%%%%%%%%%%%

% lambda in nm (column)
lambda=transpose(300:2:1000);

% calculate epsilon for ag and Au
eAg=epsAg(lambda);
eAu=epsAu(lambda);

%%%%%%%%%%%%%%%%%%
% Drawing
%%%%%%%%%%%%%%%%%%

% create, position, and resize figure
scrsz = get(0,'ScreenSize'); % scrsz(3) contains screen width
figAspectRatio=3;
figWidth=3/4*scrsz(3);
figure('Name','Fig. E.3', ...
    'Position',[(scrsz(3)-figWidth)/2 scrsz(4)-150-figWidth/figAspectRatio figWidth figWidth/figAspectRatio]);

% plot real(epsilon)
subplot(1,2,1);
plot(lambda,real(eAu),'-',lambda,real(eAg),':');
% format graph
axis([301 1000 -48 0]);
xlabel('Wavelength [nm]');
ylabel('Re(\epsilon(\omega)');
legend('Gold','Silver');

% plot imag(epsilon)
subplot(1,2,2);
plot(lambda,imag(eAu),'-',lambda,imag(eAg),':');
% format graph
axis([301 1000 0 5.9]);
xlabel('Wavelength [nm]');
ylabel('Im(\epsilon(\omega)');
legend('Gold','Silver');




