function stEllGeom = EllSphereGeomFact(a,sOption)
% Returns geometrical factors associated with a given sphere (for which a=b=c)
%
% Parameters:
% - a: scalar or row vectors [1 x G]
%      radius
% - sOptions: string (optional)
%           if 'L', only L_1 is returned
%           if 'All' (default), then all properties are returned
% Returns:
% - stEllGeom: structure with fields, all of size [1 x G]
% stEllGeom.a for future reference
% stEllGeom.S: surface area (in squared units of a, b, and c)
% stEllGeom.V: volume (in cube units of a, b, and c)
% stEllGeom.type: ='Sphere' (type of ellipsoid)
% stEllGeom.L1: Geometrical factor
% stEllGeom.exix2ave: <|e_xi . e_x|^2>
% stEllGeom.exix4ave: <|e_xi . e_x|^4>
% stEllGeom.exix2y2ave: <|e_xi . e_x|^2 |e_xi . e_y|^2>
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<4, sOption='All'; end

stEllGeom.a=a;
stEllGeom.type='Sphere'; % for reference
stEllGeom.V = 4/3*pi*a.^3;

zeroa=0*a; % zero vector, same size as a

stEllGeom.h=1+zeroa; % aspect ratio
stEllGeom.e=zeroa; % eccentricity 

% surface area
stEllGeom.S=4*pi*a.^2;

% geometrical factor
stEllGeom.L1=1/3 + zeroa;

if ~strcmpi(sOption,'L') % returns other geometrical averages

    stEllGeom.exix2ave=1/3+zeroa; 
    stEllGeom.exix4ave=1/5+zeroa;
    stEllGeom.exix2y2ave=1/15+zeroa;
end




