function epsAg = epsAg(lambda)
% Returns the wavelength-dependent relative dielectric function of silver (Ag)
% This function uses the analytical expression given in Eq. (E.1).
% The exp(-i omega t) convention is assumed.
%
% Parameters:
% - lambda: scalar, vector, or matrix
%           wavelengths in NANOMETERS (nm)
% 
% Returns:
% - epsAg: same size as lambda
%          epsilon(lambda) as a complex number.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% from Eq. E.1
eps_infty = 4.0;
lambda_p = 282.0;
mu_p = 17000.0;
epsAg = eps_infty *(1-1./(lambda_p.^2 *( (1./lambda).^2 + i./(mu_p.*lambda))));

