function epsDrude = epsDrude(lambda,eps_infty,lambda_p,mu_p)
% Returns the wavelength-dependent relative dielectric function of a Drude metal
% The analytical expression is given in Eq. (3.2).
% The exp(-i omega t) convention is assumed.
%
% Parameters:
% - lambda: scalar, vector, or matrix
%           wavelengths in NANOMETERS (nm).
% - eps_infty: scalar
%              eps_infty (see Eq. 3.2). 
% - lambda_p: scalar
%             wavelength in NANOMETERS (nm) corresponding to
%             plasma frequency omega_p [rad/s]: lambda_p=2*pi*c/(omega_p)
% - mu_p: scalar
%         wavelength in NANOMETERS (nm) corresponding to
%         damping term gamma_0 [rad/s]: mu_p=2*pi*c/(gamma_0)
% 
% Returns:
% - epsDrude: same size as lambda
%          epsilon(lambda) as a complex number.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

epsDrude = eps_infty *(1-1./(lambda_p.^2 *( (1./lambda).^2 + i./(mu_p.*lambda))));

