function [stMdip, stEfarAllP]=DipFullMonty(nNmax,a,lambda,epsilonM,epsilonIn,d,nNmaxESA,lambda0,nNbTheta)
% Solves the problem of dipole emission close to a single sphere with Mie theory and produces 4 figures to illustrate the results
% This function can also be called as DipFullMonty(stMP,lambda0,nNbTheta)
% where stMP contains the parameter fields.
% See DipSolveSingleSphere for details of the parameters.
% The results are returned in 2 structures (for further processing if needed)
% See DipSolveSingleSphere (stMdip) and DipFarFieldAllP (stEfarAllP)
% for a description of these structures.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% rearrange function parameters
if (nargin<8)
    nNmax=stMP.nNmax;
    a=stMP.a;
    lambda=stMP.lambda;
    epsilonM=stMP.epsilonM;
    epsilonIn=stMP.epsilonIn;
    d=stMP.d;
    nNmaxESA=stMP.nNmaxESA;
end

% Figure 1
% solve and plot decay rate EFs for perpendicular and parallel dipoles
stMdip=DipSolveSingleSphere(nNmax,a,lambda,epsilonM,epsilonIn,d,nNmaxESA,'plot','coeff');

% Figure 2
% Plot of decay rates EFs for other dipole orientation
px=[0 0.25 0.5 0.75 1];
pz=[1 0.75 0.5 0.25 0];
DipPlotM(stMdip,px,pz);

% Compute Radiation profiles
stEfarAllP=DipFarFieldAllP(stMdip,nNbTheta);

% Figure 3
% Plot of radiation profiles for selected wavelengths for standard cases
DipPlotEfarAllP(stEfarAllP,lambda0);

% Figure 4
% Example of plot of radiation profiles for selected wavelengths for special cases
DipPlotEfarForP(stEfarAllP,lambda0,-1,1,0,pi/4);
