function stDipEabn1bn0=DipIncEabn1bn0(nNmax,xp)
% Calculates a_{n,1}, b_{n,1}, and b_{n,0} for n=1:nNmax for the incident dipole field
% using Eqs. H.88 and H.90.
%
% Parameters:
% - nNmax:  integer scalar
% - xp:     column vector [L x 1]
%           wavelength-dependent xp=kM*Rp (Rp is distance from origin)
%
% Returns: structure with 3 fields
%          each a matrix [L x nNmax]
% - stDipEabn1bn0.an1: a_{n,1}
% - stDipEabn1bn0.bn1: b_{n,1}
% - stDipEabn1bn0.bn0: b_{n,}
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information
           

stZnAll=GenZnAll(nNmax,xp,'h1');
% Z0 is xi(xp)/xp, Z2 is (x xi)'(xp)/xp
% Z1 is xi(xp)/xp^2
n=1:nNmax;

% Parallel dipole
coeff1=3/8*(2*n+1); % [1 x nNmax]
nCoeffmat=repmat(sqrt(coeff1),length(xp),1); % [L x nNmax]

stDipEabn1bn0.an1 = i * nCoeffmat .* stZnAll.Z0;
stDipEabn1bn0.bn1 = - nCoeffmat .* stZnAll.Z2;

% Perpendicular dipole
coeff2=4*coeff1.*n.*(n+1); % [1 x nNmax]
nCoeffmat=repmat(sqrt(coeff2),length(xp),1); % [L x nNmax]

stDipEabn1bn0.bn0 = nCoeffmat .* stZnAll.Z1;
