function stDipEefn1fn0=DipIncEefn1fn0(nNmax,xp)
% Calculates e_{n,1}, f_{n,1}, and f_{n,0} for n=1:nNmax for the incident dipole field
% using Eqs. H.88 and H.90
%
% Parameters:
% - nNmax:  integer scalar
% - xp:     column vector [L x 1]
%           wavelength-dependent xp=kM*Rp (Rp is distance from origin)
%
% Returns: structure with 3 fields
%          each a matrix [L x nNmax]
% - stDipEefn1fn0.en1: e_{n,1}
% - stDipEefn1fn0.fn1: f_{n,1}
% - stDipEefn1fn0.fn0: f_{n,0}
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information
           

stZnAll=GenZnAll(nNmax,xp,'j');
% Z0 is psi(xp)/xp, Z2 is (x psi)'(xp)/xp
% Z1 is psi(xp)/xp^2
n=1:nNmax;

% Parallel dipole
coeff1=3/8*(2*n+1); % [1 x nNmax]
nCoeffmat=repmat(sqrt(coeff1),length(xp),1); % [L x nNmax]

stDipEefn1fn0.en1 = i * nCoeffmat .* stZnAll.Z0;
stDipEefn1fn0.fn1 = - nCoeffmat .* stZnAll.Z2;

% Perpendicular dipole
coeff2=4*coeff1.*n.*(n+1); % [1 x nNmax]
nCoeffmat=repmat(sqrt(coeff2),length(xp),1); % [L x nNmax]

stDipEefn1fn0.fn0 = nCoeffmat .* stZnAll.Z1;
