function DipPlotM(stMdip,px,pz)
% Plots the results of DipSolveSingleSphere as lambda-dependence of MRad and MTot
% If px and pz are not specified then results are plotted
% for both Para and Perp dipoles.
%
% Parameters:
% - stMdip: obtained from DipSolveSingleSphere or MulDipSolveMultiSphere
% - px,pz: optional vectors (same lengths) with components of dipole moment
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

lambda=stMdip.lambda;

figure('Name','Decay rate EFs');
    title(['Mie dipole emission: nNmax=' ...
        int2str(stMdip.nNmax) ', a=' num2str(stMdip.a) 'nm, d=' num2str(stMdip.d) 'nm']);

if nargin<3
    semilogy(lambda,stMdip.MRadPerp,'b-',lambda,stMdip.MTotPerp,'b:', ...
     lambda,stMdip.MRadPara,'r-',lambda,stMdip.MTotPara,'r:');
    xlabel('Wavelength [nm]');
    ylabel('Decay rate EFs');
    legend({'M_{Rad}^{Perp}','M_{Tot}^{Perp}', ...
            'M_{Rad}^{Para}','M_{Tot}^{Para}'});
else
    pxnorm2=px.^2./(px.^2+pz.^2);
    pznorm2=pz.^2./(px.^2+pz.^2);
    nNbP=length(px);
    pxnorm2=reshape(pxnorm2,1,nNbP); % ensures it is a row vector [1xP]
    pznorm2=reshape(pznorm2,1,nNbP); % ensures it is a row vector [1xP]
    % matrix products to obtain [L x P] matrices for plot
    MRad=(stMdip.MRadPara * pxnorm2) + (stMdip.MRadPerp * pznorm2);
    MTot=(stMdip.MTotPara * pxnorm2) + (stMdip.MTotPerp * pznorm2);
    
    hg=semilogy(lambda,MRad(:,1),'-');
    line(lambda,MTot(:,1),'LineStyle',':','Color',get(hg(1),'Color'));
    xlabel('Wavelength [nm]');
    ylabel('Decay rate EFs');
    CsLegend=cell(1,2*nNbP);
    CsLegend{1}=['M_{Rad} - px=' num2str(px(1)) ',pz=' num2str(pz(1))];
    CsLegend{2}=['M_{Tot} - px=' num2str(px(1)) ',pz=' num2str(pz(1))];
    % loop through additional cases for legend and colors
    hold on;
    colVec=get(gca,'ColorOrder');
    nNbCol=length(colVec);
    for pp=2:nNbP
        CsLegend{2*pp-1}=['M_{Rad} - px=' num2str(px(pp)) ',pz=' num2str(pz(pp))];
        CsLegend{2*pp}=['M_{Tot} - px=' num2str(px(pp)) ',pz=' num2str(pz(pp))];
        line(lambda,MRad(:,pp),'LineStyle','-','Color',colVec(1+mod(pp-1,nNbCol),:));
        line(lambda,MTot(:,pp),'LineStyle',':','Color',colVec(1+mod(pp-1,nNbCol),:));
    end
    legend(CsLegend);
end
title(['Mie dipole: nNmax=' int2str(stMdip.nNmax) ...
    ', nNmaxESA=' int2str(stMdip.nNmaxESA) ', a=' num2str(stMdip.a) 'nm' ...
    ', d=' num2str(stMdip.d) 'nm']);

    