function GenCheckSumNumPb(ar1,ar2,sVar,sCaller)
% Check potential loss of precision during sum of two arrays (same dimensions)
% See the supplementary information for a discussion of loss of precision.
% This function is called by all other functions checking for numerical
% precision problems and issues the warnings in case of problem.
%
% Parameters:
% - ar1: scalar, vector, or matrix
% - ar2: scalar, vector, or matrix (same dimension as ar1)
% - sVar: string describing the variable that is being calculated
% - sCaller: string describing the function in which the calculation is
%            performed
%
% Returns nothing
% Issues a warning in case of problem and allow the user to enter debug
% mode to investigate the problems further.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information


indDb= find(abs(ar1)<1e-12*abs(ar2));
if ~isempty(indDb)
    disp ' ';
    disp(['Possible numerical pb in ' sCaller ' with variable ' sVar]) 
    nbr=size(ar1,1);
    disp(['Pb with ' int2str(length(indDb)) ' indices. Details of first index where problem occurs:']);
    kk=1;
    disp(['Row ' int2str(mod(indDb(kk)-1,nbr)+1) ' Col ' int2str(floor((indDb(kk) -1)/ nbr)+1)]);
    disp(['Sum result is ' num2str(ar1(indDb(1)))]);
    disp(['Sum element is ' num2str(ar2(indDb(1)))]);
    pkey=input ('enter d for details, k for entering debug mode, or enter to continue ?','s');
    if (strcmpi(pkey,'d') || strcmpi(pkey,'k'))
        for kk=2:length(indDb)
            disp(['Row ' int2str(mod(indDb(kk)-1,nbr)+1) ' Col ' int2str(floor((indDb(kk) -1)/ nbr)+1)]);
        end
        if strcmpi(pkey,'k')
            keyboard
        end
    end
    disp ' ';
end
