% Example script to run the function MulDipFullMonty
% It produces 4 figures that illustrate the capabilities of the Mie
% codes for dipole emission close to a silver nanoshell.
% See the function MulDipFullMonty for more details.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
noCheckSum=true;
% use 'clear all' or 'clear global noChecksum' to erase noCheckSum
% clear global noCheckSum; % same as noCheckSum=false;
% noCheckSum=false;

% N_{max}
nNmax=50;
% N_{max} for ESA approximation in the evaluations of M_{Tot}
nNmaxESA=500;

% sphere radii in nm (scalar [1 x 1])
a1=70;
a2=80;

% wavelengths in nm (column vector [L x 1])
lambda=transpose(400:1:800);  

% dielectric constant of outside medium (real positive scalar)
epsilonM=1.77; % water

% wavelength-dependent dielectric function of sphere material
% vector column, same size as lambda [L x 1]
%epsilonShell=epsAg(lambda); % silver
epsilonShell=epsAu(lambda); % gold
epsilonIn=1.5^2; % silica
%epsilonIn=epsilonM;

Ca={a1,a2};
Cepsilon={epsilonIn,epsilonShell,epsilonM};

% distance of dipole from surface (in nanometer)
% note that the dipole is by convention on the positive z-axis (theta=0)
% and aligned in the (xOz) plane (py=0)
d=1;

% Number of theta for radiation profile computations
nNbTheta=361;
% selected wavelengths for radiation profile plots
lambda0=[618,487,301];

[stMdip,stEfarAllP]=MulDipFullMonty(nNmax,Ca,lambda,Cepsilon,d,nNmaxESA,lambda0,nNbTheta);

% % uncomment the following to check MRadPerp and MRadPara
% % from averages of radiated field
% figure;
% plot(lambda,stMdip.MRadPara,lambda,stEfarAllP.MRadPara, ...
%     lambda,stMdip.MRadPerp,lambda,stEfarAllP.MRadPerp);

