function [stM, stEsurf, stEfarSca, CstEmap]=MulPweFullMonty(nNmax,Ca,lambda,Cepsilon,lambda0,nNbTheta,rMax,nNbRout,CnNbRin)
% Solves the problem of PWE of a sphere multilayer with Mie theory and produces 6 figures to illustrate the results
% This function can also be called as MulPweFullMonty(stMP,lambda0,nNbTheta,rMax,nNbRout,nNbRin)
% where stMP contains the parameter fields.
% See MulPweSolveMultiSphere for details of the parameters.
% The results are returned in 4 structures (for further processing if needed)
% See MulPweSolveMultiSphere (stM), PweSurfProperties (stEsurf),
% PweFarField (stEfarSca), and PweVolProperties (CstEmap)
% for a description of these structures.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

% rearrange function parameters
if (nargin<6)
    nNmax=stMP.nNmax;
    Ca=stMP.Ca;
    lambda=stMP.lambda;
    Cepsilon=stMP.Cepsilon;
end


% Figure 1
% solve the problem and plot Q coeffs and MLocAve
stM=MulPweSolveMultiSphere(nNmax,Ca,lambda,Cepsilon,'plot','coeff');

% get theta-dep functions to avoid repeated computations
theta=linspace(0,pi,nNbTheta); % row [1 x T]
stPinTaun=PwePinTaun(stM.nNmax,transpose(theta)); % fields are [T x nNmax]

% Spherical averages and theta dependence on the largest sphere surface (outside)
stEsurf=PweSurfProperties(stM,stM.a,nNbTheta,stPinTaun);

% Figure 2
% Plot wavelength dependence surface averages
% other option is 'linear' instead of 'log'
PwePlotLdepSurfAve(stEsurf,'log');

% Figure 3
% Plot theta dependence of SERS EF on sphere surface for selected
% wavelength
% other option is 'linear' instead of 'log' (default) 
PwePlotThetaDep(stEsurf,lambda0,'log');

% Compute Radiation profile
stEfarSca=PweFarField(stM,nNbTheta,stPinTaun);
% Figure 4
% radiation profile plots at selected wavelength
PwePlotEfarSca(stEfarSca,lambda0);

% Compute electric field everywhere at ONE wavelength
CstEmap=PweVolProperties(stM,lambda0(1),rMax,nNbRout,CnNbRin,nNbTheta,stPinTaun);

% figure 5
% spatial distribution of log10(SERS EF) for phi=0 and 90d
% other options for 'Flog' are 'Flinear', 'Mlog', 'Mlinear', 'Elog,' Elinear.
% and 'half' instead of 'full'
PwePlotEmap(CstEmap,'Flog','full');

% figure 6
% Distance dependence of surface averages
PwePlotDdepSurfAve(CstEmap,'linear');

