% Example script to run the function MulPweFullMonty for a silver nanoshell
% It produces 6 figures that illustrate the capabilities of the Mie
% codes for a sphere multilayer under PWE.
% See the function MulPweFullMonty for more details.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

global noCheckSum;
noCheckSum=true;
% use 'clear all' or 'clear global noChecksum' to erase noCheckSum
% clear global noCheckSum; % same as noCheckSum=false;
% noCheckSum=false;

% N_{max}
nNmax=50;

% sphere radii in nm (scalar [1 x 1])
a1=35;
a2=50;

% wavelengths in nm (column vector [L x 1])
lambda=transpose(400:2:1200);  

% dielectric constant of outside medium (real positive scalar)
epsilonM=1.77; % water

% wavelength-dependent dielectric function of sphere material
% vector column, same size as lambda [L x 1]
%epsilonShell=epsAg(lambda); % silver
epsilonShell=epsAu(lambda); % gold
epsilonIn=1.5^2; % silica
%epsilonIn=epsilonM;

Ca={a1,a2};
Cepsilon={epsilonIn,epsilonShell,epsilonM};

nNbTheta=361;
% selected wavelengths for plots
lambda0=[664];
% Parameters to compute electric field everywhere at one wavelength
% (lambda0(1))
rMax=4*a2;
nNbRout=300;
CnNbRin={100,50};

[stMMul,stEsurfMul,stEfarScaMul,CstEmapMul]= ...
    MulPweFullMonty(nNmax,Ca,lambda,Cepsilon,lambda0,nNbTheta,rMax,nNbRout,CnNbRin);