function PwePlotDdepSurfAve(CstEmap,sLinLog)
% Plots the results of PweEmap or PweVolProperties in terms of distance dependence of surface averages
%
% Parameters:
% - CstEmap: Cell of stEmap structures
%            or simply a stEmap structure if only one.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<2, sLinLog='log'; end

nNbMap=length(CstEmap);

% create, position, and resize figure
figure('Name','Distance dependence of LFIEF averages');
if ~strcmpi(sLinLog,'linear')
    set(axes,'Yscale','log')
end
hold on;
% loop through CstEmap and do plots
for nn=1:nNbMap
    if isstruct(CstEmap) % if single structure stEmap as argument
        lambda0=CstEmap.lambda0;
        rVec=CstEmap.r;
        plot(rVec,CstEmap.MLocPerpAve,rVec,CstEmap.MLocParaAve, ...
            rVec,CstEmap.MLocAve,rVec,sqrt(CstEmap.F0E4Ave));
    else % if cell of structure stEmap as arguments
        lambda0=CstEmap{1}.lambda0; % same lambda0 for all in principle
        % lambda0 is used only for figure legend anyway
        rVec=CstEmap{nn}.r;
        plot(rVec,CstEmap{nn}.MLocPerpAve,rVec,CstEmap{nn}.MLocParaAve, ...
            rVec,CstEmap{nn}.MLocAve,rVec,sqrt(CstEmap{nn}.F0E4Ave));
    end
end

xlabel('distance from origin, r [nm]');
ylabel('Average field EFs');
legend('<M_{Loc}^{perp}>','<M_{Loc}^{//}>','<M_{Loc}>','(F_{E4}^0)^{1/2}');
title(['Distance dependence of LFIEF averages for \lambda=' num2str(lambda0) 'nm']);
hold off;

