function PwePlotEfarSca(stEfarSca, lambda0)
% Plots the radiation profiles from the results of PweFarField.
%
% Parameters:
% - stEfarSca: obtained from PweFarField
% - lambda0: scalar or vector (short vector otherwise plot would be messy)
%            wavelength(s) in nm for which the plots are done
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

lambda=stEfarSca.lambda;
theta=stEfarSca.theta;
nNbTheta=length(theta);
indNegTheta=length(theta):-1:2;
indAllTheta=[indNegTheta,1:length(theta)];
thetaAll=[-theta(indNegTheta), theta];

%indLambda=zeros(1,length(lambda0));
sLegend=cell(1,length(lambda0));
dQS1=zeros(length(lambda0),nNbTheta);
dQS2=zeros(length(lambda0),nNbTheta);
qMax=0;
qMin=1e200;
for ll=1:length(lambda0)
    ind=find(lambda==lambda0(ll),1);
    if isempty(ind)
        disp(['PwePlotEfarSca: lambda=' num2str(lambda0(ll)) ...
            ' cannot be found. Using lambda=' num2str(lambda(1)) ' instead']);
        ind=1;
    end
    % theta-dependent dQS1 and dQS2
    dQS1(ll,:)=abs(stEfarSca.S1(ind,:)).^2 /pi ./ repmat(stEfarSca.x(ind).^2,1,nNbTheta);
    dQS2(ll,:)=abs(stEfarSca.S2(ind,:)).^2 /pi ./ repmat(stEfarSca.x(ind).^2,1,nNbTheta);
    qMax=max(qMax,max(dQS1(ll,:))); % find limits for axis scale
    qMax=max(qMax,max(dQS2(ll,:)));
    qMin=min(qMin,min(dQS1(ll,:)));
    qMin=min(qMin,min(dQS2(ll,:)));
    % prepare legend for figure
    sLegend{2*ll-1}=['dQ_{Sca}^{S1}/d\Omega - \lambda=' num2str(lambda(ind))];
    sLegend{2*ll}  =['dQ_{Sca}^{S2}/d\Omega - \lambda=' num2str(lambda(ind))];
end

figure('Name','Radiation profile');
h = polar([0 2*pi], [qMin qMax]);
delete(h);
hold on;
% define four colors
scol='mbrg';
for ll=1:length(lambda0)
    polar(thetaAll,dQS1(ll,indAllTheta),scol(1+mod(ll,4)));
    polar(thetaAll,dQS2(ll,indAllTheta),[scol(1+mod(ll,4)) ':']);
end
hold off;

title('Far field radiation profiles of scattered field');
xlabel('Theta [degrees]');
ylabel('dQ/d\Omega');
legend(sLegend,'Location','EastOutside');

