function PwePlotLdepSurfAve(stEsurf,sLinLog)
% Plots the results of PweEsurf or PweSurfProperties in terms of wavelength-dependent surface averages.
%
% Parameters:
% - stEsurf: obtained from PweEsurf or PweSurfProperties
% - sLinLog: string optional
%            if sLinLog='linear', then use linear scale
%            otherwise log scale is used as default
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<2, sLinLog='log'; end

% plots Averages field EFs:
figure('Name','Wavelength dependence of LFIEF averages');

lambda=stEsurf.lambda;
plot(lambda,stEsurf.MLocPerpAve,lambda,stEsurf.MLocParaAve, ...
     lambda,stEsurf.MLocAve,lambda,sqrt(stEsurf.F0E4Ave));
 
xlabel('Wavelength [nm]');
ylabel('Average field EFs');
legend('<M_{Loc}^{perp}>','<M_{Loc}^{//}>','<M_{Loc}>','(F_{E4}^0)^{1/2}');
title(['Wavelength dependence of LFIEF averages at r=' num2str(stEsurf.r0) 'nm']);

if ~strcmpi(sLinLog,'linear')
    set(gca,'Yscale','log')
end
