function PwePlotThetaDep(stEsurf, lambda0, sLinLog)
% Plots the results of PweEsurf in terms of theta-dependent functions.
%
% Parameters:
% - stEsurf: obtained from PweEsurf or PweSurfProperties
% - lambda0: scalar or vector (short vector otherwise plot would be messy)
%            wavelength(s) in nm for which the plots are done
% - sLinLog: string optional
%            if sLinLog='linear', then use linear scale
%            otherwise log scale is used as default
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

if nargin<3, sLinLog='log'; end

lambda=stEsurf.lambda;
theta=stEsurf.theta;

indLambda=zeros(1,length(lambda0));
sLegend=cell(1,length(lambda0));
for ll=1:length(lambda0)
    ind=find(lambda==lambda0(ll),1);
    if isempty(ind)
        disp(['PwePlotThetaDep: lambda=' num2str(lambda0(ll)) ...
            ' cannot be found. Using lambda=' num2str(lambda(1)) ' instead']);
        ind=1;
    end
    indLambda(ll)=ind; 
    % prepare legend for figure
    sLegend{ll}=['F_{E4}^0(\theta,\phi=0) - \lambda=' num2str(lambda(indLambda(ll)))];
    sLegend{ll+length(lambda0)}  =['F_{E4}^0(\theta,\phi=90^\circ) - \lambda=' num2str(lambda(indLambda(ll)))];
end

% theta-dependent SERS EF for phi=0 and phi=pi/2
F0E4phi0=(abs(stEsurf.Ecr(indLambda,:)).^2+abs(stEsurf.Ect(indLambda,:)).^2).^2;
F0E4phi90=abs(stEsurf.Esf(indLambda,:)).^4;
% plot it for chosen lambda's
figure('Name','Angle-dependent SERS EFs');

plot(theta/pi*180,F0E4phi0,theta/pi*180,F0E4phi90,':');
if ~strcmpi(sLinLog,'linear')
    set(gca,'Yscale','log')
end
title(['Angle-dependent SERS EFs for r=' num2str(stEsurf.r0) 'nm']);
xlabel('Theta [degrees]');
ylabel('SERS EF');
legend(sLegend);

