% Script showing the angular dependence of the functions pi_n and tau_n
% The first figure reproduces Fig. 4.3 of Bohren and Huffman (Ref. 146),
% while the second is the same for the absolute values of the functions.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

N=4;
theta=(0:0.01:pi)'; % column
stPinTaun=PwePinTaun(N,theta);

% create, position, and resize figure for pi_n
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','PweScriptPlotPinTaun: pi_n(theta) and tau_n(theta)', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);
for n=1:N;
    % plot tau_n (assumed even of theta)
    hax=subplot(N,2,2*n-1);
    polar([-theta(end:-1:1);theta],[(stPinTaun.taun(end:-1:1,n));(stPinTaun.taun(:,n))]);
    set(hax,'Outerposition',[0,1-n/N,0.5,1.0/N]);
    title(['\tau_n, n=' int2str(n) ]);
    % plot pi_n (assumed even of theta)
    hax=subplot(N,2,2*n);
    polar([-theta(end:-1:1);theta],[(stPinTaun.pin(end:-1:1,n));(stPinTaun.pin(:,n))]);
    set(hax,'Outerposition',[0.5,1-n/N,0.5,1.0/N]);
    title(['\pi_n, n=' int2str(n) ]);
end;
% Note that to reproduce Bohren, we take pi_n and tau_n even of theta as
% above
% By defintion pi_n and tau_n should be odd of theta (although we only use
% them for theta>0
% Another vizualization is to plot the modulus of pi_n and tau_n as follows:
% create, position, and resize figure for pi_n
scrsz = get(0,'ScreenSize'); % scrsz(4) contains screen height
figAspectRatio=1;
figHeight=scrsz(4)-150;
figWidth=figAspectRatio*figHeight;
figure('Name','PweScriptPlotPinTaun: abs(pi_n(theta)) and abs(tau_n(theta))', ...
    'Position',[(scrsz(3)-figWidth)/2 50 figWidth figHeight]);
for n=1:N;
    % plot abs(tau_n)
    hax=subplot(N,2,2*n-1);
    polar([-theta(end:-1:1);theta],[abs(stPinTaun.taun(end:-1:1,n));abs(stPinTaun.taun(:,n))]);
        set(hax,'Outerposition',[0,1-n/N,0.5,1.0/N]);
    title(['|\tau_n|, n=' int2str(n) ]);
    % plot abs(pi_n)
    hax=subplot(N,2,2*n);
    polar([-theta(end:-1:1);theta],[abs(stPinTaun.pin(end:-1:1,n));abs(stPinTaun.pin(:,n))]);
    set(hax,'Outerposition',[0.5,1-n/N,0.5,1.0/N]);
    title(['|\pi_n|, n=' int2str(n) ]);
end;

