% Script for symbolic expressions for the lowest orders pi_n and tau_n angular functions
% pi_n and tau_n are defined as in Bohren and Huffman (Ref. 146).
% See also the SPlaC supplementary information.
% This script requires the Matlab symbolic toolbox to run.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

nNmax=8;
syms t positive; % t for theta

% This code follows the method of PwePinTaun

mu=cos(t);
nrows=1; % only one theta here
% Initialize recurrence pi_0=0, pi_1=1
% pinm1 contains pi_{n-1} n=1..nNmax+1
pinm1=zeros(nrows,nNmax+1) * t; % for symbolic zeros
pinm1(:,2)=zeros(nrows,1) * t +1; % for symbolic ones

% Get pi_2 to pi_nNmax by recurrence (see SPlaC guide)
% pi_n is pinm1(:,n+1)
for n=2:(nNmax)
    pinm1(:,n+1)=(2*n-1)/(n-1)*mu.*pinm1(:,n)-n/(n-1)*pinm1(:,n-1);
end;

% return pi_n matrix (except n=0)
pin=pinm1(:,2:(nNmax+1));

% return tau_n matrix
nmat=repmat(1:nNmax,nrows,1);
mumat=repmat(mu,1,nNmax);
taun=nmat.*mumat.*pin - (nmat+1).*pinm1(:,1:nNmax);

% Write output:
disp(' ')
for n=1:(nNmax)
    disp(['pi_' int2str(n) '(t)= ' char(factor(pin(1,n)))])
    disp(['tau_' int2str(n) '(t)= ' char(factor(taun(1,n)))])
    disp(' ')
end;    