% Script for symbolic expressions for the lowest orders p_n and t_n angular functions
% p_n and t_n relates to the angular dependence for m=0 (used for
% perpendicular dipoles).
% They are defined and discussed in the SPlaC supplementary information.
% This script requires the Matlab symbolic toolbox to run.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

nNmax=8;
syms t positive; % t for theta

% This code follows the method of DipPinTaunPnTn
nrows=1; % only one theta here, T=1
muc=cos(t);
mus=sin(t);

% Initialize recurrence p_0=1, p_1=muc, t_0=0, t_1=-mus
% pnm1 contains p_{n-1} n=1..nNmax+1, same for tnm1
pnm1=t*zeros(nrows,nNmax+1)+1; % [T x N+1]
pnm1(:,2)=muc; % [T x 1]
tnm1=t*zeros(nrows,nNmax+1); % [T x N+1]
tnm1(:,2)=-mus; % [T x 1]

% Get p_2 to p_nNmax and t_2 to t_nNmax by recurrence
% p_n is pnm1(:,n+1), t_n is tnm1(:,n+1)
for n=2:(nNmax)
    pnm1(:,n+1)=(2*n-1)/(n)*muc.*pnm1(:,n)-(n-1)/n*pnm1(:,n-1);
    tnm1(:,n+1)=muc.*tnm1(:,n)-n*mus.*pnm1(:,n);
end;

% return p_n and t_n matrices (except n=0)
pn=pnm1(:,2:(nNmax+1));
tn=tnm1(:,2:(nNmax+1));

% Write output:
disp(' ')
for n=1:(nNmax)
    disp(['p_' int2str(n) '(t)= ' char(factor(pn(1,n)))])
    disp(['t_' int2str(n) '(t)= ' char(factor(tn(1,n)))])
    disp(' ')
end;    