% Script for symbolic expressions for the lowest orders spherical Bessel functions and their Taylor expansions for small argument
% This script requires the Matlab symbolic toolbox to run.
%
% This file is part of the SPlaC v1.0 package (copyright 2008)
% Check the README file for further information

nNmax=3;
nTaylor=9;
syms x positive; % use x real positive for better simplification

nm1=0:nNmax;
nu=nm1+0.5;

fjnm1=besselj(nu,x);
fh1nm1=fjnm1+1i*bessely(nu,x);

sq=sqrt((pi/2)./x); % [R x 1]
sqmat=repmat(sq,1,nNmax+1); % [R x nNmax+1]
fjnm1=fjnm1.*sqmat;
fh1nm1=fh1nm1.*sqmat;
% fjnm1 and fh1nm1  are now matrix of spherical Bessel
% j_n(rho), n=0..nNmax or equivalently j_{n-1}(rho), n=1..nNmax+1

% Write output:
disp('Functions:')
disp(' ')
for n=1:(nNmax+1)
    disp(['j_' int2str(n-1) '(x)= ' char(simplify(fjnm1(n)))])
    disp(['h1_' int2str(n-1) '(x)= exp(i*x)* [' char(simple(factor(fh1nm1(n))/(cos(x)+1i*sin(x)))) ']'])
    disp(' ')
end;

% Write output:
disp('Taylor expansions around x=0:')
disp(' ')
n=1;
for n=1:(nNmax+1)
    disp(['j_' int2str(n-1) '(x)= x^' int2str(n-1) '* [' ...
        char(taylor(simplify(fjnm1(n))/x^(n-1),x,'Order',nTaylor+2*n)) ']'])
    disp(['h1_' int2str(n-1) '(x)= 1/x^' int2str(n) '* [' ...
        char(taylor(simplify(factor(fh1nm1(n))*(x^n)),x,'Order',nTaylor)) ']'])
    disp(' ')
end;

